@@ -148,7 +148,6 @@ Defaults to the version currently running (%s)." % LOCAL_MACOS_VERSION))
 
         SIZED_MASK = os.path.join(temp_folder, "%s_1.0_SIZED_MASK.png" % name)
         try:
-            print()
             subprocess.check_call(p(
                 convert_path,
                 g(
@@ -224,11 +223,11 @@ or
 
         COMPOSITE = g(
             template_icon,
+            WHITE_SHADOW,
+            "-compose", "dissolve", "-composite",
             FILL,
             "-compose", "dissolve", "-composite",
             BLACK_SHADOW,
-            "-compose", "dissolve", "-composite",
-            WHITE_SHADOW,
             "-compose", "dissolve", "-composite"
         )
 
@@ -341,6 +340,7 @@ or
             os.mkdir(iconset_folder)
 
             print_prefix = target
+            print("[%s] => assign to [%s]" % (mask, target))
         else:
             root, _ = os.path.splitext(mask)
             iconset_folder = root + ".iconset"
